/* BEGIN software license
 *
 * MsXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2026 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the MsXpertSuite project.
 *
 * The MsXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
 * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef USER_SPEC_HPP
#define USER_SPEC_HPP


/////////////////////// Qt includes
#include <QString>


namespace MsXpS
{

namespace MassXpert
{


class UserSpec
{
  private:
  QString m_userName;
  QString m_configDir;
  QString m_workDir;
  QString m_dataDir;

  public:
  UserSpec();

  ~UserSpec();

  void setUserName(const QString & = QString(""));
  const QString &userName() const;

  void setConfigDir(const QString &);
  const QString &configDir() const;

  void setWorkDir(const QString &);
  const QString &workDir() const;

  void setdataDir(const QString &);
  const QString &dataDir() const;
};

} // namespace MassXpert

} // namespace MsXpS


#endif // USER_SPEC_HPP
